==> tencent_trtc_cloud-0.0.2.tar.gz: lib/trtc_cloud_video_view.dart <==
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';

/// 视频view窗口,显示本地视频、远端视频或辅流
///
/// 参数：
///
/// key: Widget key，可以不传
///
/// onViewCreated: view创建后的回调，生成的当前viewId
class TRTCCloudVideoView extends StatefulWidget {
  final ValueChanged<int> onViewCreated;
  const TRTCCloudVideoView({
    Key key,
    this.onViewCreated,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() => TRTCCloudVideoViewState();
}

//// @nodoc
class TRTCCloudVideoViewState extends State<TRTCCloudVideoView> {
  /// channel标识符
  static const String type = "trtcCloudChannelView";

  @override
  Widget build(BuildContext context) {
    if (Platform.isAndroid) {
      return AndroidView(
        viewType: type,
        onPlatformViewCreated: _onPlatformViewCreated,
      );
    } else if (Platform.isIOS) {
      return UiKitView(
        viewType: type,
        onPlatformViewCreated: _onPlatformViewCreated,
      );
    } else {
      return Text("该平台不支持Platform View");
    }
  }

  void _onPlatformViewCreated(int id) {
    widget.onViewCreated(id);
  }
}

/// @nodoc
/// 视频控制器方法
class TRTCCloudVideoViewController {
  TRTCCloudVideoViewController(int id)
      : _channel = new MethodChannel('trtcCloudChannelView_$id');

  final MethodChannel _channel;

  /// 开启本地视频的预览画面
  ///
  /// 当开始渲染首帧摄像头画面时，您会收到 TRTCCloudListener 中的 onFirstVideoFrame(null) 回调。
  ///
  /// 参数：
  ///
  /// frontCamera	true：前置摄像头；false：后置摄像头
  Future<void> startLocalPreview(
    bool frontCamera, // true：前置摄像头；false：后置摄像头。
  ) {
    return _channel.invokeMethod('startLocalPreview', {
      "frontCamera": frontCamera,
    });
  }

  /// 显示远端视频或辅流
  ///
  /// 参数：
  ///
  /// userId 指定远端用户的 userId
  ///
  /// streamType 指定要观看 userId 的视频流类型：
  ///
  ///* 高清大画面：TRTCCloudDef.TRTC_VIDEO_STREAM_TYPE_BIG
  ///
  ///* 低清大画面：TRTCCloudDef.TRTC_VIDEO_STREAM_TYPE_SMALL
  ///
  ///* 辅流（屏幕分享）：TRTCCloudDe.TRTC_VIDEO_STREAM_TYPE_SUB
  Future<void> startRemoteView(
      String userId, // 用户ID
      int streamType) {
    return _channel.invokeMethod(
        'startRemoteView', {"userId": userId, "streamType": streamType});
  }
}

==> tencent_trtc_cloud-0.0.4.tar.gz: lib/trtc_cloud_video_view.dart <==
import 'dart:io';
import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';
import 'trtc_cloud_def.dart';

/// @no-doc
/// channel标识符
String channelType = "trtcCloudChannelView";

/// 视频view窗口,显示本地视频、远端视频或辅流
///
/// 参数：
///
/// onViewCreated: view创建后的回调，生成的当前viewId
///
/// key: Widget key，可以不传
///
/// viewType: 该参数仅对安卓有效，可以不传
///
/// 安卓视频渲染所用的view组件类型，有两个组件可以选择SurfaceView和TextureView。默认为TextureView
///
/// 如果想用TextureView进行渲染，则viewType传TRTCCloudDef.TRTC_VideoView_TextureView
///
/// 如果想用SurfaceView进行渲染，则viewType传TRTCCloudDef.TRTC_VideoView_SurfaceView
class TRTCCloudVideoView extends StatefulWidget {
  final ValueChanged<int> onViewCreated;
  final int viewType;
  const TRTCCloudVideoView({
    Key key,
    this.viewType,
    this.onViewCreated,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() => TRTCCloudVideoViewState(this.viewType);
}

//// @nodoc
class TRTCCloudVideoViewState extends State<TRTCCloudVideoView> {
  TRTCCloudVideoViewState(int viewType) {
    if (viewType == TRTCCloudDef.TRTC_VideoView_SurfaceView) {
      channelType = "trtcCloudChannelSurfaceView";
    } else {
      channelType = "trtcCloudChannelView";
    }
  }
  @override
  Widget build(BuildContext context) {
    if (Platform.isAndroid) {
      return AndroidView(
        viewType: channelType,
        onPlatformViewCreated: _onPlatformViewCreated,
      );
    } else if (Platform.isIOS) {
      return UiKitView(
        viewType: channelType,
        onPlatformViewCreated: _onPlatformViewCreated,
      );
    } else {
      return Text("该平台不支持Platform View");
    }
  }

  void _onPlatformViewCreated(int id) {
    widget.onViewCreated(id);
  }
}

/// @nodoc
/// 视频控制器方法
class TRTCCloudVideoViewController {
  TRTCCloudVideoViewController(int id)
      : _channel = new MethodChannel(channelType + '_$id');

  final MethodChannel _channel;

  /// 开启本地视频的预览画面
  ///
  /// 当开始渲染首帧摄像头画面时，您会收到 TRTCCloudListener 中的 onFirstVideoFrame(null) 回调。
  ///
  /// 参数：
  ///
  /// frontCamera	true：前置摄像头；false：后置摄像头
  Future<void> startLocalPreview(
    bool frontCamera, // true：前置摄像头；false：后置摄像头。
  ) {
    return _channel.invokeMethod('startLocalPreview', {
      "frontCamera": frontCamera,
    });
  }

  /// 显示远端视频或辅流
  ///
  /// 参数：
  ///
  /// userId 指定远端用户的 userId
  ///
  /// streamType 指定要观看 userId 的视频流类型：
  ///
  ///* 高清大画面：TRTCCloudDef.TRTC_VIDEO_STREAM_TYPE_BIG
  ///
  ///* 低清大画面：TRTCCloudDef.TRTC_VIDEO_STREAM_TYPE_SMALL
  ///
  ///* 辅流（屏幕分享）：TRTCCloudDe.TRTC_VIDEO_STREAM_TYPE_SUB
  Future<void> startRemoteView(
      String userId, // 用户ID
      int streamType) {
    return _channel.invokeMethod(
        'startRemoteView', {"userId": userId, "streamType": streamType});
  }
}
